package FDN::Adsl::Controller::Base;

use strict;
use warnings;
use base 'Catalyst::Controller';

use FDN::Web::Array;
use FDN::Adsl::Utils ();

sub default :Path('') {
	my ( $self, $c ) = @_;
	$c->encoding(Encode::find_encoding('latin1'));
	$c->detach('liste');
}

sub eject_error :Private {
	my ( $self, $c, $message ) = @_;
	my $page = '<div class="error">'.$message.'</div>';
	$self->eject_page($c,$page);
}

sub eject_page :Private {
	my ( $self, $c, $page ) = @_;
	$c->encoding(Encode::find_encoding('latin1'));
	if ( $c->req->param('ajax') ) {
		$c->detach('TT', 'ajax', [ { 'PAGE' => $page, 'encoding' => 'latin1' }] );
	} else {
		$c->detach('TT', 'final', [ 'base2.tt', { 'PAGE' => $page, 'encoding' => 'latin1' }] );
	}
}

sub eject_ajax :Private {
	my ( $self, $c, $page ) = @_;
	$c->encoding(Encode::find_encoding('latin1'));
	$c->detach('TT', 'ajax', [ { 'PAGE' => $page, 'encoding' => 'latin1' }] );
}

sub ajax_links {
	my $self = shift;
	my ( $c, $links ) = @_;
	my $res;
	for my $l ( sort keys %$links ) {
		$res .= '<a class="command" onclick="ajax_fetch(this,\''.$links->{$l}.'\')">'.$l.'</a>';
	}
	$res = '<div class="commands">'.$res.'</div>';
	return $res;
}

sub small_table_1d {
	my $self = shift;
	my ( $c, $table, $infos, $title, $links ) = @_;
	my $vars = {};
	if ( ! defined $infos ) {
		$vars->{'table'} = "<h1>$title</h1>\n".
			"<div class=\"tbl1d\">\n".
			"<table class=\"tbl1d\"><tr><td>Cet lment n'existe pas</td></tr></table>\n".
			"</div>\n";
	} else {
		$vars->{'table'} = tableau_1d('adsl/rewrite.tbl', $table, $infos, $title);
	}
	$vars->{'links'} = $links // {};
	return $c->forward('TT','partial', ['table_tiers.tt',$vars]);
}

# Affichera un total des colonnes _HT et _TTC et en deduire un montant de TVA
# $col_prefix permet de trouver les colonnes  totaliser.
sub large_table_2d_pognon {
	my $self = shift;
	my ( $c, $table, $col_prefix, $liste, $title, $links ) = @_;
        my $vars = {};
	$vars->{'table'} = tableau_2d_pognon('adsl/rewrite.tbl', $table, $col_prefix, $liste, $title);
        $vars->{'links'} = $links // {};
	return $c->forward('TT','partial', ['table_full.tt',$vars]);
}

sub large_table_2d {
	my $self = shift;
	my ( $c, $table, $liste, $title, $links ) = @_;
        my $vars = {};
	$vars->{'table'} = tableau_2d('adsl/rewrite.tbl', $table, $liste, $title);
        $vars->{'links'} = $links // {};
	return $c->forward('TT','partial', ['table_full.tt',$vars]);
}

sub add_forward :Private {
	my $self = shift;
	my ( $label, $url ) = @_;
	return "(<a href=\"$url\">$label</a>)"
}

sub back_from :Private {
	my ( $self, $c, $frominfo ) = @_;
	$frominfo =~ /^(\D*)(\d*)$/;
	my ( $from, $fid ) = ( $1, $2 );
	if ( ! defined $FDN::Adsl::Utils::froms->{$from} ) {
		$c->log->debug("From $from n'est pas defini (lu depuis $frominfo).");
		return $c->res->redirect('/adsl');
	}

	my $frm = $FDN::Adsl::Utils::froms->{$from};
	my $url = $frm->{'url'};
	$url .= '?'.$frm->{'id'}.'='.$fid.'&do=yes';
	$c->log->debug("Back to url $url");
	return $c->res->redirect($url);
}


1;
