package FDN::Adsl::Controller::Client;

use strict;
use warnings;
use base 'FDN::Adsl::Controller::Base';

use DateTime;
use POSIX qw(strftime);

use FDN::Common::Config;
use FDN::Common::Modules;
use FDN::Web::Array;
use FDN::Web::Forms;

use FDN::Adsl::Basic;
use FDN::Adsl::Infos;
use FDN::Adsl::Liste;
use FDN::Adsl::New;
use FDN::Adsl::Utils;
use FDN::Adsl::Prelevemt;
use FDN::Adsl::Purge;
use FDN::Adsl::Numadh;
use FDN::Adsl::Ag;
use FDN::Adsl::Radius;

__PACKAGE__->config->{'namespace'} = 'adsl/client';

sub __search_form {
	my ( $val ) = @_;
	my $form = '<form action="/adsl/client/liste/search" method="GET">'.
		'<label for="name">Texte recherch dans le nom</label>'.
		'<input name="name" type="text" value="'.$val.'"/>'.
		'<input type="submit" name="submit" value="Ok" />'.
		'</form>';
	return $form;
}

sub __tous_clients_vieux {
	my $annee = (strftime "%Y", localtime) - 4;
	my $limite = "$annee-01-01 00:00:00";
	my $liste = [ tous_clients_resilies(), tous_clients_init() ];
	my %seen = ();
	$liste = [ grep { ! $seen{$_->{CLIENT_ID}}++ } @$liste ];
	$liste = [ grep { my $date = client_date_derniere_operation($_->{CLIENT_ID}); $date ne "0000-00-00" and $date < $limite } @$liste ];
	return $liste;
}

sub search :Local {
	my ( $self, $c ) = @_;
	my $page = __search_form('');
	$c->detach('Base','eject_page',[ $page ]);
}

sub liste :Local {
	my ( $self, $c, $what ) = @_;
	$what //= 'all';

	my ( $liste, $name, $page );
	if ( $what eq 'act' ) {
		$liste = [ tous_clients_actifs() ];
		$name = "Liste des adhrent.es actif.ves (<a href=\"all\">Tous</a>) (<a href=\"resil\">Resilie.es</a>) (<a href=\"init\">En cours</a>) (<a href=\"vieux\">Vieux</a>)";
	} elsif ( $what eq 'resil' ) {
		$name = "Liste des adhrent.es resilie.es (<a href=\"all\">Tous</a>) (<a href=\"act\">Actif.ves</a>) (<a href=\"init\">En cours</a>) (<a href=\"vieux\">Vieux</a>)";
		$liste = [ tous_clients_resilies() ];
	} elsif ( $what eq 'init' ) {
		$name = "Liste des adhrent.es non initialiss (<a href=\"all\">Tous</a>) (<a href=\"act\">Actif.ves</a>) (<a href=\"resil\">Resilie.es</a>) (<a href=\"vieux\">Vieux</a>)";
		$liste = [ tous_clients_init() ];
		$liste = [ grep { $_->{CLIENT_TYPE} ne 'blanche' and $_->{CLIENT_TYPE} ne 'collecte' } @$liste ];
	} elsif ( $what eq 'vieux' ) {
		$name = "Liste des vieux.eilles adhrent.es (<a href=\"all\">Tous</a>) (<a href=\"act\">Actif.ves</a>) (<a href=\"resil\">Resilie.es</a>) (<a href=\"init\">En cours</a>) (<a href=\"purgevieux\">Purger les vieux</a>)";
		$liste = __tous_clients_vieux();
	} elsif ( $what eq 'search' ) {
		my $val = $c->req->param('name');
		$page = __search_form($val);
		$name = "Recherche par nom";
		$liste = [ client_par_nom_like($val) ];
	} elsif ( $what eq 'all' ) {
		$name = "Liste des adhrent.es (<a href=\"act\">Actif.ves</a>) (<a href=\"resil\">Resilie.es</a>) (<a href=\"init\">En cours</a>)";
		$liste = [ tous_clients() ];
	} else {
		$c->detach('Base','eject_page',[ "Je n'ai pas compris, tu veux $what ??" ]);
	}

	if ( $#$liste == 0 ) {
		my $cid = $liste->[0]->{'CLIENT_ID'};
		$c->res->redirect('/adsl/client/view?cid='.$cid.'&do=yes');
		return;
	}

	my $sort = $c->req->param('sort');
	if ( !$sort || $sort eq "" ) {
		$sort = "CLIENT_ID";
	}
	
	if ( $sort eq 'DERNIERE_OPERATION' ) {
		for my $c ( @$liste ) {
			$c->{DERNIERE_OPERATION} = client_date_derniere_operation($c->{CLIENT_ID});
		}
	}

	if ( $sort =~ /(_ID|_NUM)/ ) {
		$liste = [ sort { $a->{$sort} <=> $b->{$sort} } @$liste ];
	} else {
		$liste = [ sort { $a->{$sort} cmp $b->{$sort} } @$liste ];
	}

	$page .= tableau_2d('adsl/rewrite.tbl', 'client', $liste, $name);
	$c->detach('Base','eject_page',[ $page ]);
}

sub view :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $page;

	my $form = form_read('adsl/form/view.cfg','vclient');

	if ( $vars->{'do'} ne 'yes' ) {
		$page = affiche_form($form,$vars);
	} elsif ( !check_transition($form,$vars) ) {
		$page = affiche_form($form,$vars);
	}

	my $cid = $vars->{'cid'};
	my $tel = $vars->{'tel'};
	my $num = $vars->{'numadh'};

	if ( ! $page && ! $cid && ! $tel && ! $num ) {
		add_form_error('mandatory',"Il faut quand meme renseigner un des trois champs");
		$page = affiche_form($form,$vars);
	}

	if ( $page ) {
		$c->detach('Base','eject_page',[ $page ]);
	}


	my $client;
	if ( $cid ) {
		$client = client_par_id($cid);
	} elsif ( $num ) {
		$client = client_par_numadh($num);
	} else {
		my $ligne = ligne_par_tel($tel);
		if ( defined $ligne ) {
			$cid = $ligne->{'CLIENT_ID'};
			$client = client_par_id($cid);
		}
	}

	if ( ! defined $client ) {
		$c->detach('Base','eject_error',["Ce client n'existe pas"]);
	}
	$cid = $client->{'CLIENT_ID'};
	$num = $client->{'CLIENT_NUMADH'};

	my $setadh = '';
	if ( $client->{'CLIENT_NUMADH'} == -1 ) {
		$setadh = ' '.forward_to('numadh',$cid,"client$cid");
	}

	$page .= $self->small_table_1d($c,'client-detail',$client,"Description de l'abonn.e", {
		'Edition' => "/adsl/client/new?id=$cid",
	});
	
	my $aid;
	$aid = $client->{'ADRESSE_ID'};
	my $adresse;
	$adresse = adresse_par_id($aid);
	$page .= $self->small_table_1d($c,'adresse',$adresse,"Adresse de l'abonn.e", {
		Edition => "/adsl/adresse/new?id=$aid&cid=$cid&from=client$cid"
	});
	
	my $access;
	$access = adhaccess_par_client_id($cid);
	if ( $access ) {
		my $accid = $access->{'ADHACCESS_ID'};
		$page .= $self->small_table_1d($c,'adhaccess',$access,"Accs tableau de bord",{
			Edition => "/adsl/adhaccess/new?id=$accid&from=client$cid"
		});
	} else {
		$page .= $self->small_table_1d($c,'adhaccess',undef,"Accs tableau de bord",{
			Creation => "/adsl/adhaccess/new?from=client$cid&client=$cid"
		});
	}
	
	my @validations = validation_par_client_id($cid);
	if ( @validations ) {
		$page .= $self->large_table_2d($c, 'validation', \@validations, 'Validations en attente');
	}

	$page .= $self->ajax_links($c, {
		'Voir les infos' => "/adsl/infos/liste?client=$cid&ajax=1"
	});

	$page .= $self->ajax_links($c, {
		'Voir les lignes' => "/adsl/ligne/liste?cid=$cid&ajax=1",
		'Voir les payants' => "/adsl/payant/liste?client=$cid&ajax=1",
		'Voir les VPN' => "/adsl/vpn/liste?cid=$cid&ajax=1",
		'Voir les dons' => "/adsl/don/liste?cid=$cid&ajax=1",
	});

	$page .= $self->ajax_links($c, {
		'Voir les comptes bancaires' => "/adsl/prelevemt/liste?client=$cid&ajax=1",
		'Voir les crances' => "/adsl/creance/liste?client=$cid&ajax=1",
		'Voir les factures' => "/adsl/facture/liste?client=$cid&ajax=1",
		'Voir les paiements' => "/adsl/paiement/liste?client=$cid&ajax=1",
		'Voir les prlvements ETEBAC' => "/adsl/prllig/liste?client=$cid&ajax=1",
		'Voir les prlvements SEPA' => "/adsl/prlligsepa/liste?client=$cid&ajax=1",
	});

#	my @users = unixuser_par_client_id($cid);
#	$page .= tableau_2d('adsl/rewrite.tbl','unixuser',\@users,
#		'Utilisateurs unix '.
#		forward_to('nunixuser',$cid,"client-technique$cid"));

#	my @sites = site_par_client_id($cid);
#	$page .= tableau_2d('adsl/rewrite.tbl','site',\@sites,
#		"Sites de l'abonn ".
#		forward_to('nsite',$cid,"client-technique$cid"));

#	my @doms = domaine_par_client_id($cid);
#	$page .= tableau_2d('adsl/rewrite.tbl','domaine',\@doms,
#		 "Domaines de l'abonn ".
#		 forward_to('ndomaine',$cid,"client-technique$cid"));

	$c->detach('Base','eject_page',[ $page ]);

}

sub activate_prelevemt :Local {
	my ( $self, $c ) = @_;

	my $cid = $c->req->params->{'cid'};
	my $pid = $c->req->params->{'pid'};
	set_client_prelevemt($cid, $pid);
	$c->res->redirect("/adsl/client/view?cid=$cid&do=yes");
}

sub _new :Path('new') {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;

	my $form = form_client($vars);
	my $cid = $vars->{id};
	my $client = client_par_id($cid);

	if ( $vars->{'do'} ne 'yes' ) {
		renseigne_client($vars,$cid);
		$c->detach('Base','eject_page',[ affiche_form($form,$vars) ]);
	}
	if ( !check_transition($form,$vars) ) {
		$c->detach('Base','eject_page',[ affiche_form($form,$vars) ]);
	}

	if ($vars->{'etat'} eq 'resilie') {
		desabonne_liste_ag($cid);
		desabonne_liste_accueil($cid);
	}
	if ($client->{CLIENT_ETAT} eq 'resilie' and $vars->{'etat'} eq 'actif') {
		abonne_liste_ag($cid);
	}

	modifie_client($vars,$cid);
	$c->res->redirect("/adsl/client/view?cid=$cid&do=yes");
}


sub purge :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $page;

	my $form = form_read('adsl/form/purge.cfg','purgeclient');

	my $cid = $vars->{'cid'};
	my $client;
	if ( $cid > 0 ) {
		$client = client_par_id($cid);
		my $info = $self->small_table_1d($c, 'client-detail', $client, 'Client.e  purger');
		form_set_field_value($form->{'byname'}->{'htmlinfo'},$info);
	}

	if ( $vars->{'do'} ne 'yes' ) {
		$c->detach('Base','eject_page',[ affiche_form($form,$vars) ]);
	}

	if ( !check_transition($form,$vars) ) {
		$c->detach('Base','eject_page',[ affiche_form($form,$vars) ]);
	}

	purge_client($cid);
	$c->res->redirect('/adsl/client/resil?sort=DERNIERE_OPERATION');
}

sub purgevieux :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $page = "";

	my $form = form_read('adsl/form/purge.cfg','purgevieux');

	my $liste = __tous_clients_vieux();
	$liste = [ sort { $a->{CLIENT_ID} <=> $b->{CLIENT_ID} } @$liste ];

	if ( $vars->{'do'} ne 'yes'
	  or !check_transition($form,$vars) ) {
		$page .= affiche_form($form,$vars);

		my $name = "Liste des vieux.eilles adhrent.es que l'on s'apprte  supprimer";

		$page .= tableau_2d('adsl/rewrite.tbl', 'client', $liste, $name);

		$c->detach('Base','eject_page',[ $page ]);
	}

	for my $cli (@$liste) {
		purge_client($cli->{CLIENT_ID});
		$page .= "<br/>j'ai supprim le client $cli->{CLIENT_ID}\n";
	}

	$c->detach('Base','eject_page',[ $page ]);
}

sub numadh :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $cid = $vars->{'client'};
	my $form = form_nadh($vars);

	if ( $vars->{'do'} ne 'yes' ) {
		$vars->{'client'} = $cid;
		$vars->{'prix'} = 81;
		$vars->{'libelle'} = 'Adhesion FDN';
		$vars->{'type'} = 'annuel';
		$vars->{'date'} = '';
		$vars->{'debut'} = DateTime->now->ymd;
		$vars->{'fin'} = '2035-12-31 00:00:00';
		$c->detach('Base','eject_page',[ affiche_form($form,$vars) ]);
	}

	if ( !check_transition($form,$vars) ) {
		$c->detach('Base','eject_page',[ affiche_form($form,$vars) ]);
	}

	# Donner un numro d'adhrent
	my $num = init_numadh($cid);
	$c->log->info("Recu le numero d'adherent.e '$num'");
	
	if ( $num ) {
		# Ajouter un payant
		$c->log->info("On va lui ajouter un payant");
		modifie_payant($vars,undef);
		# Inscrire  la liste ag@ et accueil@
		$c->log->info("Et on va l'abonner aux listes AG et accueil");
		abonne_liste_ag($cid);
		abonne_liste_accueil($cid);
		conduse('FDN::Adsl::Ldap');
		FDN::Adsl::Ldap::ldap_update_client($cid);
		# Creation du compte radius pour acceder au site des adminsys
		$c->log->info("On lui cree un compte radius pour apache");
		my $ad = adhaccess_par_client_id($cid);
		create_radius_adh($ad->{'ADHACCESS_ID'}, $ad->{'ADHACCESS_LOGIN'}, $ad->{'ADHACCESS_PASSWD'}); 
	} else {
		$c->log->error("Echec. Pas pu attribuer un numero d'adherent au client '$cid'");
	}

	my $from = $vars->{'from'};
	$c->detach('Base','back_from', [$from]);

}


1;
