package FDN::Adsl::Controller::Cloture;

use strict;
use warnings;
use base 'FDN::Adsl::Controller::Base';

use DateTime;
use FDN::Web::Forms;

use FDN::Adsl::Basic;
use FDN::Adsl::New;
use FDN::Adsl::Utils;
use FDN::Adsl::Factu;

__PACKAGE__->config->{'namespace'} = 'adsl/cloture';


sub _new :Path('new') {
	my ( $self, $c ) = @_;

	$c->detach('Base','eject_error',[ "On n'dite pas les clotures comme a !" ]);
### 	my $vars = $c->req->params;
### 	my $creance;
### 
### 	my $form = form_creance($vars);
### 	my $crid = $vars->{'id'};
### 
### 	if ( $vars->{'do'} ne 'yes' ) {
### 		renseigne_creance($vars,$crid);
### 		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
### 	}
### 	if ( !check_transition($form,$vars) ) {
### 		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
### 	}
### 	modifie_creance($vars,$crid);
### 	my $from = $vars->{'from'};
### 	$c->detach('Base','back_from', [$from]);
}

sub liste :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	if ( $vars->{'annees'} ) {
		my @cls = toutes_clotures();
		my $annees = {};
		for my $cl ( @cls ) {
			my $date = $cl->{'CLOTURE_DATE'};
			$date =~ s/^(\d{4}).*$/$1/;
			$annees->{$date} //= 0;
			$annees->{$date}++;
		}
		my $page = $c->forward('TT','partial',['annees_clotures.tt',{ annees => $annees }]);
		$c->detach('Base','eject_page',[$page]);
	} elsif ( $vars->{'recentes'} ) {
		my $limit = $vars->{'recentes'};
		my @cls = clotures_recentes($limit);
		my $page = $self->large_table_2d($c, 'cloture', \@cls, "Clotures rcentes", {
			'Clore un mois' => '/adsl/cloture/clore',
			'Clotures par annes' => '?annees=1'
		});
		$c->detach('Base','eject_page',[$page]);
	} elsif ( $vars->{'annee'} ) {
		my $annee = $vars->{'annee'};
		my @cls = cloture_par_annee($annee);
		my $page = $self->large_table_2d($c, 'cloture', \@cls, "Clotures pour l'anne $annee", {
			'Clotures par annes' => '?annees=1'
		});
		$c->detach('Base','eject_page',[$page]);
	}

	$c->detach('Base','eject_error',["C'est idiot de vouloir lister toutes les clotures"]);
}

sub recap_creances {
	my ($libelle, $crs) = @_;

	my $total_ht = 0;
	my $total_ttc = 0;

	for my $cr ( @$crs ) {
		$total_ht += $cr->{'CREANCE_HT'};
		$total_ttc += $cr->{'CREANCE_TTC'};
	}

	my $recap = ();
	$recap->{RECAP_LIBELLE} = $libelle;
	$recap->{RECAP_HT} = $total_ht;
	$recap->{RECAP_TTC} = $total_ttc;

	return $recap;
}

sub view :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $page;

	my $form = form_read('adsl/form/view.cfg','vcloture');
	if ( $vars->{'do'} ne 'yes' ) {
        	$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}
	if ( !check_transition($form,$vars) ) {
        	$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}

	my $cid = $vars->{'cid'};
	my $cloture = $vars->{'cloture'};

	if ( !$cid and !$cloture ) {
		add_form_error('mandatory',"Il faut quand meme renseigner un des deux champs");
		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}

	my $cl;
	if ( $cid ) {
		$cl = cloture_par_id($cid);
	} else {
		$cloture =~ /^(\d\d)\/(\d{4})/;
		my $dt = "$2$1";
		$cl = cloture_par_date($dt);
	}

	if (! defined $cl ) {
		$c->detach('Base','eject_error',["Cette cloture n'existe pas"]);
	}

	$cid = $cl->{'CLOTURE_ID'};
	$page = $self->small_table_1d($c,'cloture',$cl,"Description de la cloture");

	my @crs = creance_par_cloture_id($cid);
	@crs = sort { $a->{CREANCE_ID} <=> $b->{CREANCE_ID} } @crs;

	my @crs_adh = grep { $_->{'PRIX_ID'} >= 81 && $_->{'PRIX_ID'} <= 89 } @crs;
	@crs = grep { !($_->{'PRIX_ID'} >= 81 && $_->{'PRIX_ID'} <= 89) } @crs;

	my @crs_adsl = grep {
		($_->{'PRIX_ID'} >= 1 && $_->{'PRIX_ID'} <= 79) ||
		($_->{'PRIX_ID'} >= 201 && $_->{'PRIX_ID'} <= 319) ||
		($_->{'PRIX_ID'} >= 601 && $_->{'PRIX_ID'} <= 639)
	} @crs;
	@crs = grep  {
		!($_->{'PRIX_ID'} >= 1 && $_->{'PRIX_ID'} <= 79) &&
		!($_->{'PRIX_ID'} >= 201 && $_->{'PRIX_ID'} <= 319) &&
		!($_->{'PRIX_ID'} >= 601 && $_->{'PRIX_ID'} <= 639)
	} @crs;

	my @crs_vpn = grep { $_->{'PRIX_ID'} >= 501 && $_->{'PRIX_ID'} <= 509 } @crs;
	@crs = grep { !($_->{'PRIX_ID'} >= 501 && $_->{'PRIX_ID'} <= 509) } @crs;

	my @crs_services = grep { $_->{'PRIX_ID'} >= 91 && $_->{'PRIX_ID'} <= 99 } @crs;
	@crs = grep { !($_->{'PRIX_ID'} >= 91 && $_->{'PRIX_ID'} <= 99) } @crs;

	$page .= $self->large_table_2d_pognon($c,'creance','CREANCE',\@crs_adh,"Creances adhesion");
	$page .= $self->large_table_2d_pognon($c,'creance','CREANCE',\@crs_adsl,"Creances ADSL");
	$page .= $self->large_table_2d_pognon($c,'creance','CREANCE',\@crs_vpn,"Creances VPN");
	$page .= $self->large_table_2d_pognon($c,'creance','CREANCE',\@crs_services,"Creances Services");
	$page .= $self->large_table_2d_pognon($c,'creance','CREANCE',\@crs,"Autres creances");

	my @recaps;

	push @recaps, recap_creances("Adhsions", \@crs_adh);
	push @recaps, recap_creances("ADSL", \@crs_adsl);
	push @recaps, recap_creances("VPN", \@crs_vpn);
	push @recaps, recap_creances("Services", \@crs_services);
	push @recaps, recap_creances("Autres", \@crs);

	$page .= $self->large_table_2d_pognon($c,'recap_creance','RECAP',\@recaps,"Rcap");

	$c->detach('Base','eject_page',[$page]);
}

sub clore :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;

	my $last = clotures_recentes(1);
	my $date = $last->{'CLOTURE_DATE'};
	$date =~ /^(\d\d\d\d)(\d\d)$/;
	my ( $annee, $mois ) = ( $1, $2 );

	my $page = '<h3>Dernire cloture connue: anne '.$annee.', mois '.$mois.'</h3>';
	$mois++;
	if ( $mois > 12 ) {
		$annee++;
		$mois='01'; 
	}
	$page .= '<p>Prochaine cloture raisonnable: anne '.$annee.', mois '.$mois.'</p>';
	$page .= '<p>Les valeurs par dfaut ont t positionnes en ce sens.</p>';
	$vars->{'mois'} //= 'mois'.$mois;
	$vars->{'annee'} //= 'annee'.$annee;

	my $form = form_read('adsl/form/factu.cfg','cmois');
	if ( $vars->{'do'} ne 'yes' ) {
		$page .= affiche_form($form,$vars);
		$c->detach('Base','eject_page', [ $page ] );
	}
	if ( !check_transition($form,$vars) ) {
		$page .= affiche_form($form,$vars);
		$c->detach('Base','eject_page', [ $page ] );
	}

	# Cloture effective du mois
	$annee = $vars->{annee};
	$annee =~ s/^annee//;
	$mois = $vars->{mois};
	$mois  =~ s/^mois//;

	my $mois_suivant = $mois + 1;
	my $annee_suivante = $annee;
	if ( $mois_suivant > 12 ) {
		$annee_suivante++;
		$mois_suivant = 1;
	}
	my $date = DateTime->new(year => $annee_suivante, month => $mois_suivant, day => 1);
	my $now = DateTime->now;

	if ( $now->ymd lt $date->ymd ) {
		$c->detach('Base','eject_error', [ "Ce mois n'est pas fini, on ne peut pas le clturer." ] );
	}
	
	my $clid = cloture_mois($annee,$mois);
	if ( $clid ) {
		$c->res->redirect('/adsl/cloture/view?cid='.$clid.'&do=yes');
	}

	$c->detach('Base','eject_error', [ "chec de la cloture. Il faut plucher les logs." ] );

}

1;
