package FDN::Adsl::Controller::Compta;

use strict;
use warnings;
use base 'FDN::Adsl::Controller::Base';

use FDN::Common::Config;
use FDN::Web::Array;
use FDN::Web::Forms;

use FDN::Adsl::Utils;
use FDN::Adsl::Basic;
use FDN::Adsl::Infos;
use FDN::Adsl::New;

__PACKAGE__->config->{'namespace'} = 'adsl/compta';

sub default :Path('') {
	my ( $self, $c ) = @_;
	$c->detach('liste');
}

sub liste :Local {
	my ( $self, $c, $what ) = @_;
	$what //= 'all';

	my $page;
	my $vars = $c->req->params;
	my $liste;
	if ( $vars->{'state'} ) {
		$liste = [ compta_par_etat($vars->{'state'}) ];
	} elsif ( $vars->{'asso'} ) {
		$liste = [ compta_par_asso($vars->{'asso'}) ];
	} elsif ( $what eq 'all' ) {
		$liste = [ tous_comptas() ];
	} else {
		$c->detach('Base','eject_page',[ "Je n'ai pas compris, tu veux $what ??" ]);
	}
	
	$page .= $self->large_table_2d($c, 'compta', $liste, "Liste des groupes de documents", {
		'Ajouter' => '/adsl/compta/new'
	});
	$c->detach('Base', 'eject_page', [ $page ]);
}

sub view :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $page;

	my $form = form_read('adsl/form/view.cfg','vcompta');
	if ( $vars->{'do'} ne 'yes' ) {
		$c->detach('Base', 'eject_page', [ affiche_form($form,$vars) ] );
	}
	if ( !check_transition($form,$vars) ) {
		$c->detach('Base', 'eject_page', [ affiche_form($form,$vars) ] );
	}

	my $cid = $vars->{'cid'};
	my $compta = compta_par_id($cid);
	$page .= $self->small_table_1d($c,'compta',$compta, "Un groupe de documents ", {
		'Modifier' => '/adsl/compta/new?id='.$cid.'&from=compta'.$cid,
		'Liste' => '/adsl/compta/liste'
	});

	my @infos = toutes_infos_compta($cid);
	@infos = sort { $a->{INFO_ID} <=> $b->{INFO_ID} } @infos;
	$page .= $self->large_table_2d($c,'infos',\@infos, "Documents dans ce groupe ", {
		'Scanner' => '/adsl/new-scan.cgi?doctype=compta&compta='.$cid
	});
	$c->detach('Base', 'eject_page', [ $page ]);
}

sub do_new :Path('new') {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $id = $vars->{id};

	my $form = form_compta($vars);

	my $page;
	if ( $vars->{'do'} ne 'yes' ) {
		renseigne_compta($vars,$id);
		$page = affiche_form($form,$vars);
	} elsif ( ! check_transition($form,$vars) ) {
		$page = affiche_form($form,$vars);
	}
	if ( $page ) {
		$c->detach('Base', 'eject_page', [ $page ] );
	}

	modifie_compta($vars,$id);
	my $from = $vars->{'from'};
	$from //= 'compta'.$id;
	$c->detach('Base','back_from', [$from]);
}


1;
