package FDN::Adsl::Controller::Don;

use strict;
use warnings;
use base 'FDN::Adsl::Controller::Base';

#### use FDN::Web::Array;
use FDN::Web::Forms;

use FDN::Common::Utils;
use FDN::Adsl::Basic;
use FDN::Adsl::New;
use FDN::Adsl::Liste;
use FDN::Adsl::Utils;

__PACKAGE__->config->{'namespace'} = 'adsl/don';


sub xnew :Path('new') {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $don_id = $vars->{'id'};

	my $form = form_don($vars);
	if ( $vars->{'do'} ne 'yes' ) {
		renseigne_don($vars,$don_id);
		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}
	if ( !check_transition($form,$vars) ) {
		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}
	modifie_don($vars,$don_id);
	my $from = $vars->{'from'};
	$c->detach('Base','back_from', [$from]);
}

sub liste :Local {
	my ( $self, $c, $what ) = @_;
	$what //= 'all';

	my $page;
	if ( $c->req->param('cid') ) {
		my $cid = $c->req->param('cid');
		my $dons = [ don_par_client_id($cid) ];
		$dons = [ sort { $a->{DON_ID} <=> $b->{DON_ID} } @$dons ];
		$page = $self->large_table_2d($c, 'don', $dons, "Dons de l'abonn", {
			'Ajouter' => "/adsl/don/new?client=$cid&from=client$cid"
		});
	} elsif ( $what eq 'all' ) {
		my @dons = tous_don();
		my $total_vpn = 0;
		my $total = 0;
		for my $don (@dons) {
			next if ($don->{DON_TYPE} eq 'ponctuel');
			next if ($don->{DON_STATE} ne 'ok');
			next if ($don->{DON_DEBUT} ge get_timestamp());
			next if ($don->{DON_FIN} lt get_timestamp());

			my $montant;

			if ($don->{DON_TYPE} eq 'mensuel') {
				$montant = $don->{DON_MONTANT};
			} elsif ($don->{DON_TYPE} eq 'annuel') {
				$montant = $don->{DON_MONTANT} / 12;
			}

			if ($don->{DON_LIBELLE} eq 'Don vpnopen') {
				$total_vpn += $montant;
			}

			$total += $montant;
		}
		$total = sprintf("%.2f", $total / 100);
		$total_vpn = sprintf("%.2f", $total_vpn / 100);
		$page = "<p>Total mensuel VPN open-bar: $total_vpn&nbsp;&euro;</p>";
		$page .= "<p>Total mensuel: $total&nbsp;&euro;</p>";

		my $sort = $c->req->param('sort');
		$page .= liste_dons($sort);
	} else {
		$c->detach('Base','eject_page',[ "Je n'ai pas compris, tu veux $what ??" ]);
	}

	$c->detach('Base', 'eject_page', [ $page ] );
}

sub view :Local {
	my ( $self, $c, $iid ) = @_;

	my $vars = $c->req->params;
	my $page;

	my $form = form_read('adsl/form/view.cfg','vdon');
	if ( $vars->{'do'} ne 'yes' ) {
		$page = affiche_form($form,$vars);
		$c->detach('Base','eject_page',[$page]);
		return;
		$c->detach('Base','eject_page', [ $page ]);
	}
	if ( !check_transition($form,$vars) ) {
		$page = affiche_form($form,$vars);
		$c->detach('Base','eject_page', [ $page ]);
	}

	my $don_id = $vars->{'did'};
	my $don = don_par_id($don_id);

	if ( ! defined $don ) {
		$c->detach('Base','eject_error',["Ce don n'existe pas."]);
	}

        $page .= $self->small_table_1d($c,'don',$don,"Un don", {
                'Edition' => "/adsl/don/new?id=$don_id&from=don$don_id"
        });

	$c->detach('Base','eject_page', [ $page ]);
}

1;
