package FDN::Adsl::Controller::Facture;

use strict;
use warnings;
use base 'FDN::Adsl::Controller::Base';

# Usefull ?
use FDN::Common::Config;
use FDN::Common::Modules;
use FDN::Web::TemplateParse;

use FDN::Web::Array;
use FDN::Web::Forms;

use FDN::Adsl::Basic;
use FDN::Adsl::New;
use FDN::Adsl::Utils;
use FDN::Adsl::Factu;

__PACKAGE__->config->{'namespace'} = 'adsl/facture';


sub liste :Local {
	my ( $self, $c, $what ) = @_;
	$what //= 'all';

	my $vars = $c->req->params;
	my $page;
	my $facs;
	my $none;

	if ( $vars->{'client'} ) {
		my $cid = $vars->{'client'};
		$facs = [ facture_par_client_id($cid) ];
		$facs = [ sort { $a->{FACTURE_ID} <=> $b->{FACTURE_ID} } @$facs ];
		$none = "Il n'y a pas de facture pour ce client";
	} elsif ( $vars->{'state'} ) {
		my $state = $vars->{'state'};
		$facs = [ facture_par_etat($state) ];
		$none = "Il n'y a pas de facture dans l'tat '$state'";
	} elsif ( $what eq 'all' ) {
		$facs = [ toutes_factures() ];
		$none = "Il n'y a pas de facture dans la base";
	} else {
		$c->detach('Base','eject_page',[ "Je n'ai pas compris, tu veux $what ??" ]);
	}
	if ( $#$facs == -1 ) {
		$c->detach('Base', 'eject_error', [ $none ] );
	}
	$page = $self->large_table_2d($c, 'facture', $facs, "Liste des factures");

	$c->detach('Base','eject_page', [ $page ] );
		
}

sub view :Local {
	my ( $self, $c, $iid ) = @_;

	my $vars = $c->req->params;
	my $page;

	my $form = form_read('adsl/form/view.cfg','vfacture');
	if ( $vars->{'do'} ne 'yes' ) {
		$page = affiche_form($form,$vars);
		$c->detach('Base','eject_page', [ $page ]);
	}
	if ( !check_transition($form,$vars) ) {
		$page = affiche_form($form,$vars);
		$c->detach('Base','eject_page', [ $page ]);
	}

	my $fid = $vars->{'fid'};
	my $fac = facture_par_id($fid);

	if (! defined $fac ) {
		$c->detach('Base','eject_error',["Cette facture n'existe pas."]);
	}

	$page .= $self->small_table_1d($c, 'facture', $fac, "Description de la facture ", {
		'Imprimer' => "/adsl/facture/print?factu=factu$fid&format=pdf&do=yes",
		'Export texte' => "/adsl/facture/print?factu=factu$fid&format=text&do=yes"
	});

	my $crs = [ creance_par_facture_id($fid) ];
	$crs = [ sort { $a->{CREANCE_ID} <=> $b->{CREANCE_ID} } @$crs ];
	$page .= $self->large_table_2d_pognon($c, 'creance', 'CREANCE', $crs, "Crances couvertes par la facture");

	$c->detach('Base','eject_page', [ $page ]);
}

sub paye :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $page;

	my $form = form_read('adsl/form/factu.cfg','Pfactu');
	ajoute_liste_factures_envoyees($form);
	if ( $vars->{'do'} ne 'yes' ) {
		$page = affiche_form($form,$vars);
		$c->detach('Base','eject_page', [ $page ]);
	}
	if ( !check_transition($form,$vars) ) {
		$page = affiche_form($form,$vars);
		$c->detach('Base','eject_page', [ $page ]);
	}

	# Paiement de la facture
	my $fid = $vars->{factu};
	encaisser_facture($fid);
	$c->res->redirect('/adsl');
}

sub envoie :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $page;

	my $form = form_read('adsl/form/factu.cfg','efactu');
	ajoute_liste_factures_dues($form);
	if ( $vars->{'do'} ne 'yes' ) {
		$page = affiche_form($form,$vars);
		$c->detach('Base','eject_page', [ $page ]);
	}
	if ( !check_transition($form,$vars) ) {
		$page = affiche_form($form,$vars);
		$c->detach('Base','eject_page', [ $page ]);
	}

	# Envoi de la facture
	my $fid = $vars->{factu};
	set_facture_etat($fid,'envoyee');
	$c->res->redirect('/adsl');
}

sub crea1 :Local {
	my ( $self, $c ) = @_;

	my $cls = [ tous_clients() ]; # tous les clients peuvent demander des factures!
	if ( ! @$cls ) {
		$c->detach('Base', 'eject_error', [ "Nous n'avons pas de clients!" ]);
	}

	my $rcls = [];
	for my $cl ( @$cls ) {
		my $cid = $cl->{'CLIENT_ID'};
		my $crs = [ creance_par_client_id_etat($cid,'due') ];
		$crs = [ sort { $a->{CREANCE_ID} <=> $b->{CREANCE_ID} } @$crs ];
		$cl->{'nbcr'} = @$crs;
		if ( ! @$crs ) {
			next;
		}
		my $ttc = 0;
		for my $cr ( @$crs ) {
			$ttc += $cr->{'CREANCE_TTC'};
		}
		$cl->{'ttc'} = $ttc;
		push @$rcls, $cl;
	}

	if ( ! @$rcls ) {
		$c->detach('Base', 'eject_error', [ "Aucun client n'a de dette" ] );
	}

	my $page = $self->large_table_2d($c, 'creafac', $rcls, "Clients ayant des dettes");
	$c->detach('Base', 'eject_page', [ $page ]);
}

sub crea2 :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $page;

	# Creation effective de la facture
	my $cid = $vars->{cid};
	my $crs = [ creance_par_client_id_etat($cid,'due') ];
	$crs = [ sort { $a->{CREANCE_ID} <=> $b->{CREANCE_ID} } @$crs ];

	if ( ! @$crs ) {
		$c->detach('Base', 'eject_error', [ "Ce client ne doit rien" ]);
	}

	my $fid = creation_facture($cid,$crs);
	$page = 'La facture <a href="/adsl/facture/view?fid='.$fid.'&do=yes">'.$fid.'</a> a t cre';
	$c->detach('Base', 'eject_page', [ $page ] );
}

sub crea3 :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $page;

	# Creation effective de la facture
	my $cid = $vars->{cid};
	solder_des_creances($cid);

	crea1($self, $c);
}

sub print :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;

	my $form = form_read('adsl/form/factu.cfg','pfactu');
	# Ajoute toutes les factures, dans l'ordre (due, envoyee, payee)
	ajoute_liste_factures($form);
	if ( $vars->{'do'} ne 'yes' ) {
		$c->detach('Base', 'eject_page', [ affiche_form($form,$vars) ] );
	}
	if ( !check_transition($form,$vars) ) {
		$c->detach('Base', 'eject_page', [ affiche_form($form,$vars) ] );
	}

	# Affichage de la facture
	my $hash = {};

	my $fid = $vars->{factu};
	$fid =~ s/^factu//;
	my $facture = facture_par_id($fid);
	$hash->{'facture'} = $facture;

	my $cid = $facture->{'CLIENT_ID'};
	my $client = client_par_id($cid);
	$hash->{'client'} = $client;

	my $aid = $client->{'ADRESSE_ID'};
	my $adresse = adresse_par_id($aid);
	$hash->{'adresse'} = $adresse;

	my $crs = [ creance_par_facture_id($fid) ];
	$crs = [ sort { $a->{CREANCE_ID} <=> $b->{CREANCE_ID} } @$crs ];

	if ( $vars->{format} eq 'html' ) {
		my $page = $c->forward('View::TT', 'partial', [ 'facture_head.tt', $hash ] );
		$page .= $self->large_table_2d_pognon($c, 'facture-html', 'CREANCE', $crs);
		$c->detach('Base', 'eject_page', [ $page ]);
	}
#	if ( $vars->{format} eq 'text' ) {
#		$hash->{tableau} = tableau_2d_pognon_text('adsl/rewrite.tbl','facture-text','CREANCE',\@crs);
#		my $dir = Config_Key('adsl/global.cfg','dirs','texttpl');
#		my $page = remplace($dir.'/facture.tpl',$hash,1);
#		eject_page_text($page);
#	}
	if ( $vars->{format} eq 'pdf' ) {
		my $file = imprimer_facture($cid, $fid);
		$c->detach('File','pdf',[ $file ]);
	}

}

1;
