package FDN::Adsl::Controller::Infos;

use strict;
use warnings;
use base 'FDN::Adsl::Controller::Base';

use FDN::Web::Array;

use FDN::Adsl::Basic;
use FDN::Adsl::Infos;


__PACKAGE__->config->{'namespace'} = 'adsl/infos';


sub _new :Path('new') {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;

	if ( $vars->{'do'} ne 'yes' ) {
		my $page = $c->forward('TT','partial',[ 'newinfo_form.tt', $vars ]);
		$c->detach('Base','eject_page',[ $page ]);
	}

	my $title = $vars->{'title'};
	my $texte = $vars->{'texte'};

	my $iid;
	if ( exists $vars->{'client'} && $vars->{'client'} ) {
		my $cid = $vars->{'client'};
		$iid = new_info_client($cid,'inline',$title,$texte);
		$c->res->redirect("/adsl/client/view?cid=$cid&do=yes");
	} elsif ( exists $vars->{'ligne'} && $vars->{'ligne'} ) {
		my $lid = $vars->{'ligne'};
		$iid = new_info_ligne($lid,'inline',$title,$texte);
		$c->res->redirect("/adsl/ligne/view?lid=$lid&do=yes");
	} elsif ( exists $vars->{'vpn'} && $vars->{'vpn'} ) {
		my $vid = $vars->{'vpn'};
		$iid = new_info_vpn($vid,'inline',$title,$texte);
		$c->res->redirect("/adsl/vpn/view?vid=$vid&do=yes");
	} elsif ( exists $vars->{'compta'} && $vars->{'compta'} ) {
		my $cid = $vars->{'compta'};
		$iid = new_info_compta($cid,'inline',$title,$texte);
	} else {
		$c->detach('Base','eject_error',[ 'Problme avec le formulaire : aucun rattachement pour l\'info saisie...' ]);
	}
	$c->detach('Infos','view',[ $iid ]);
}

sub liste :Local {
	my ( $self, $c ) = @_;

	my $infos;
	my $title;
	my $params = $c->req->params;
	if ( exists $params->{'client'} && $params->{'client'} ) {
		my $cid = $params->{'client'};
		my $client = client_par_id($cid);
		if ( ! $client ) {
			$c->detach('Base','eject_error',["Ce client n'existe pas."]);
		}
		$infos = [ toutes_infos_client($cid) ];
		$infos = [ sort { $a->{INFO_ID} <=> $b->{INFO_ID} } @$infos ];
		$title = "Informations sur le client ".$client->{'CLIENT_NOM'}." adhrent <a href=\"/adsl/client/view?do=yes&cid=$cid\">".$client->{'CLIENT_NUMADH'}." (id=".$cid.")</a>";
		$title .= ' (<a href="/adsl/infos/new?client='.$cid.'">Ajouter</a>)';
	} elsif ( exists $params->{'ligne'} && $params->{'ligne'} ) {
		my $lid = $params->{'ligne'};
		my $ligne = ligne_par_id($lid);
		if ( ! $ligne ) {
			$c->detach('Base','eject_error',['Cette ligne n\'existe pas']);
		}
		my $cid = $ligne->{'CLIENT_ID'};
		my $client = client_par_id($cid);
		if ( ! $client ) {
			$c->detach('Base','eject_error',['Cette ligne existe, mais est attache  un client qui n\'existe pas.']);
		}
		$infos = [ toutes_infos_ligne($lid) ];
		$infos = [ sort { $a->{INFO_ID} <=> $b->{INFO_ID} } @$infos ];
		$title = "Informations sur la ligne ".$ligne->{'LIGNE_TEL'}." pour ".$client->{'CLIENT_NOM'}." adh=".$client->{'CLIENT_NUMADH'}." cid=".$cid." lid=".$lid;
	} elsif ( exists $params->{'vpn'} && $params->{'vpn'} ) {
		my $vid = $params->{'vpn'};
		$infos = [ toutes_infos_vpn($vid) ];
		$infos = [ sort { $a->{INFO_ID} <=> $b->{INFO_ID} } @$infos ];
		$title = "Informations sur le VPN";
	} elsif ( exists $params->{'compta'} && $params->{'compta'} ) {
		my $cid = $params->{'compta'};
		$infos = [ toutes_infos_compta($cid) ];
		$infos = [ sort { $a->{INFO_ID} <=> $b->{INFO_ID} } @$infos ];
		$title = "Informations dans la catgorie comptable";
	} elsif ( exists $params->{'id'} && $params->{'id'} ) {
		my $iid = $params->{'id'};
		$infos = [ info_par_id($iid) ];
		$infos = [ sort { $a->{INFO_ID} <=> $b->{INFO_ID} } @$infos ];
		$title = "Information";
	} else {
		# Il ne faut pas faire a...
		$c->detach('Base','eject_error',['Ce lien est idiot. Il voudrait lister <b>toutes</b> les infos contenues dans le SI. Il ne faut pas faire a.']);
	}

	my $page = tableau_2d('adsl/rewrite.tbl','infos',$infos,$title);
#		"Informations sur la ligne".
#		forward_to('nscan',"&ligne=$lid&client=$cid","ligne$lid"));

	$c->detach('Base','eject_page',[ $page ]);
}

sub view :Local :Args(1) {
	my ( $self, $c, $iid ) = @_;

	my $info = info_par_id($iid);
	if ( ! defined $info ) {
		$c->detach('Base','eject_error',[ "Cette info n'existe pas." ]);
	}

	if ( $info->{'INFO_TYPE'} eq 'inline' ) {
		$c->detach('Base','eject_page', [ "<div>".$info->{'INFO_VAL'}."</div>" ] );
	} else {
		$c->detach('Base','eject_page', [ '<a href="view-image.cgi?name='.$info->{'INFO_VAL'}.'">Fichier</a>' ]);
	}
	$c->detach('Base','eject_page',[ "On ne devrait jamais arriver ici..." ]);
}

1;
