package FDN::Adsl::Controller::Paiement;

use strict;
use warnings;
use base 'FDN::Adsl::Controller::Base';

use FDN::Web::Array;
use FDN::Web::Forms;

use FDN::Adsl::Basic;
use FDN::Adsl::New;
use FDN::Adsl::Utils;

__PACKAGE__->config->{'namespace'} = 'adsl/paiement';


sub xnew :Path('new') {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;

	my $form = form_paiement($vars);
	my $pid  = $vars->{'pid'};

	if ( $vars->{'do'} ne 'yes' ) {
		renseigne_paiement($vars,$pid);
		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}
	if ( !check_transition($form,$vars) ) {
		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}

	modifie_paiement($vars,$pid);

	my $from = $vars->{'from'};
	$c->detach('Base','back_from', [$from]);
}

sub liste :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;

	my $page;
	if ( $vars->{'client'} ) {
		my $cid = $vars->{'client'};
		my $pais = [ paiement_par_client_id($cid) ];
		$pais = [ sort { $a->{PAIEMENT_ID} <=> $b->{PAIEMENT_ID} } @$pais ];
		$page .= $self->large_table_2d($c, 'paiement', $pais, "Paiements de l'abonn", {
			'Ajouter' => "/adsl/paiement/new?client=$cid&from=client$cid"
		});
	}

	if ( $page ) {
		$c->detach('Base', 'eject_page', [ $page ] );
	}

	$c->detach('Base','eject_error',["C'est idiot de vouloir lister des paiements en vrac"]);
}

sub view :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $page;

	my $form = form_read('adsl/form/view.cfg','vpaiement');
	if ( $vars->{'do'} ne 'yes' ) {
		$page = affiche_form($form,$vars);
		$c->detach('Base','eject_page', [ $page ]);
	}
	if ( !check_transition($form,$vars) ) {
		$page = affiche_form($form,$vars);
		$c->detach('Base','eject_page', [ $page ]);
	}

	my $pid = $vars->{'pid'};
	my $num = $vars->{'numero'};

	if ( ! $pid && ! $num ) {
		add_form_error('mandatory',"Il faut quand meme renseigner un des deux champs");
		$page = affiche_form($form,$vars);
		$c->detach('Base','eject_page', [ $page ]);
	}

	my $paiement;
	if ( $pid ) {
		$paiement = paiement_par_id($pid);
	} else {
		$paiement = paiement_par_num($num);
	}

	if ( ! defined $paiement ) {
		$c->detach('Base','eject_error',["Ce paiement n'existe pas."]);
	}

	$page .= $self->small_table_1d($c, 'paiement', $paiement, "Un paiement ", {
		'Edition' => "/adsl/paiement/new?pid=$pid&from=paiement$pid"
	});

	$c->detach('Base','eject_page', [ $page ]);
}

1;
