package FDN::Adsl::Controller::Payant;

use strict;
use warnings;
use base 'FDN::Adsl::Controller::Base';

use FDN::Web::Array;
use FDN::Web::Forms;

use FDN::Adsl::Basic;
use FDN::Adsl::New;
use FDN::Adsl::Utils;
use FDN::Adsl::Factu;
use FDN::Adsl::Infos;
use FDN::Common::Modules;

use Time::Local;

__PACKAGE__->config->{'namespace'} = 'adsl/payant';


sub xnew :Path('new') {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $paid = $vars->{'id'};

	my $form = form_payant($vars);
	if ( $vars->{'do'} ne 'yes' ) {
		renseigne_payant($vars,$paid);
		conduse('Date::Format');

		# Calcul de fin de bimestre, seulement pour Nerim.
		#  supprimer quand a ne sera plus le cas majoritaire.
		my ($s,$m,$h,$jour,$mois,$annee) = localtime(time);
		my ( $jourfin, $moisfin, $anneefin );
		if ($mois % 2 == 0) {
                        # On est le premier mois du bimestre, on pousse juste au
			# mois prochain.
			$moisfin = $mois + 1;
		} else {
                        # On est le deuxime mois du bimestre, on repousse
                        # ventuellement de deux mois si c'est trop tard dans le
			# mois
			if ($jour >= 15) {
				$moisfin = $mois + 2;
			} else {
				$moisfin = $mois;
			}
		}
		if ($moisfin >= 12) {
			# Oups, on change d'anne
			$moisfin -= 12;
			$anneefin = $annee + 1;
		} else {
			$anneefin = $annee;
		}
		# Dernier jour
		my @joursfin = jours($anneefin);
		$jourfin = $joursfin[$moisfin];

		my $date = time2str("%Y-%m-%d 00:00:00", timelocal(0, 0, 0, $jour, $mois, $annee));
		my $datefin = time2str("%Y-%m-%d 00:00:00", timelocal(0, 0, 0, $jourfin, $moisfin, $anneefin));

		if (! defined($vars->{'date'})) {
			$vars->{'date'} = $date;
		}
		if (! defined($vars->{'debut'})) {
			$vars->{'debut'} = $date;
		}
		if (! defined($vars->{'fin'})) {
			$vars->{'fin'} = $datefin;
		}
		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}
	if ( !check_transition($form,$vars) ) {
		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}
	if ($vars->{'type'} eq 'unique') {
		$vars->{'debut'} = undef;
		$vars->{'fin'} = undef;
	} else {
		$vars->{'date'} = undef;
	}
	my $newpaid = modifie_payant($vars,$paid);

	if ($newpaid != $paid) {
		new_info_client($vars->{'client'}, 'inline', "Nouveau payant", "$newpaid par ".$c->req->remote_user);
	} else {
		new_info_client($vars->{'client'}, 'inline', "Modification payant", "$paid par ".$c->req->remote_user);
	}

	my $from = $vars->{'from'};
	$c->detach('Base','back_from', [$from]);
}

sub liste :Local {
	my ( $self, $c ) = @_;

	if ( $c->req->param('client') ) {
		my $cid = $c->req->param('client');
		my $payants = [ payant_par_client_id($cid) ];
		$payants = [ sort { $a->{PAYANT_ID} <=> $b->{PAYANT_ID} } @$payants ];
		my $page = $self->large_table_2d($c, 'payant', $payants, "Items payants de l'abonn", {
			'Ajouter' => "/adsl/payant/new?client=$cid&from=client$cid"
		});
		$c->detach('Base', 'eject_page', [ $page ] );
	}

	$c->detach('Base','eject_error',["C'est idiot de vouloir lister des payants en vrac"]);
}

sub view :Local {
	my ( $self, $c, $iid ) = @_;

	my $vars = $c->req->params;
	my $page;

	my $form = form_read('adsl/form/view.cfg','vpayant');
	if ( $vars->{'do'} ne 'yes' ) {
		$page = affiche_form($form,$vars);
		$c->detach('Base','eject_page',[$page]);
		return;
		$c->detach('Base','eject_page', [ $page ]);
	}
	if ( !check_transition($form,$vars) ) {
		$page = affiche_form($form,$vars);
		$c->detach('Base','eject_page', [ $page ]);
	}

	my $pid = $vars->{'pid'};
	my $payant = payant_par_id($pid);

	if ( ! defined $payant ) {
		$c->detach('Base','eject_error',["Cet item payant n'existe pas."]);
	}

        $page .= $self->small_table_1d($c,'payant',$payant,"Un item payant", {
                'Edition' => "/adsl/payant/new?id=$pid&from=payant$pid"
        });

	$c->detach('Base','eject_page', [ $page ]);
}

1;
