package FDN::Adsl::Controller::Prelevemt;

use strict;
use warnings;
use base 'FDN::Adsl::Controller::Base';

use FDN::Common::Config;
use FDN::Web::Array;
use FDN::Web::Forms;

use FDN::Adsl::Utils;
use FDN::Adsl::Basic;
use FDN::Adsl::Infos;
use FDN::Adsl::New;
use FDN::Adsl::Prelevemt;
use FDN::TeX::TeX;

__PACKAGE__->config->{'namespace'} = 'adsl/prelevemt';

sub default :Path('') {
	my ( $self, $c ) = @_;
	$c->detach('liste');
}

sub liste :Local {
	my ( $self, $c ) = @_;

	my $params = $c->req->params;
	if ( exists $params->{'client'} ) {
		my $cid = $params->{'client'};
		my $prels = prelevemt_du_client($cid);
		my $page = $self->large_table_2d($c,'prelevemt',$prels,"Comptes bancaires de l'abonn",{
			'Ajouter' => '/adsl/prelevemt/new?cid='.$cid
		});
		$c->detach('Base','eject_page',[$page]);
	}
	$c->detach('Base','eject_error',["Lister tous les comptes bancaires connus du SI, ce n'est pas une bonne ide."]);
}

sub view :Local {
	my ( $self, $c ) = @_;

	my $page;
	my $prel;
	my $vars = $c->req->params;
	my $plid = $vars->{'plid'};
	if ( $plid ) {
		$prel = prelevemt_par_id($plid);
	}
	if ( ! $prel ) {
		$page = '<h3>Choisir un compte</h3>'.
			'<form action="view" method="GET">'.
			'<label for="id">Id.</label> <input type="text" name="id" />'.
			'<input type="submit" name="submit" value="Ok" />'.
			'</form>';
		$c->detach('Base','eject_page',[$page]);
	}

	$page = $c->forward('Base','small_table_1d',[ 'prelevemt', $prel, "Un prlvement", {
		'Modifier' => 'new?id='.$plid.'&do=yes&from=prelevemt'.$plid
	}]);
	$c->detach('Base','eject_page',[$page]);
}

sub xnew :Path('new') {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $form = form_prelevemt($vars);
	my $pid  = $vars->{'id'};
	my $page;

	if ( $vars->{'do'} ne 'yes' || !check_transition($form,$vars) ) {
		$c->log->info('Editer le prel');
		renseigne_prelevemt($vars,$pid);
		$page = affiche_form($form,$vars);
		$c->detach('Base','eject_page',[$page]);
	}

	my $bq = $vars->{'banque'};
	my $gu = $vars->{'guichet'};
	my $cp = $vars->{'compte'};
	my $cl = $vars->{'rib'};
	if ( $bq ) {
		if ( ! verif_clef_rib($bq,$gu,$cp,$cl) ) {
			$c->log->info('Clef RIB invalide');
			add_form_error('syntax',"Le compte est invalide apres controle de la clef");
			$page = affiche_form($form,$vars);
			$c->detach('Base','eject_page',[$page]);
		}
		modifie_prelevemt($vars,$pid);
	}

	$vars->{'iban'} =~ s/ //g;
	my $bic  = $vars->{'bic'};
	my $iban = $vars->{'iban'};
	if ( $bic ) {
		if ( ! verif_clef_iban($iban) ) {
			$c->log->info('Clef IBAN invalide');
			add_form_error('syntax',"Le compte est invalide apres controle de la clef");
			$page = affiche_form($form,$vars);
			$c->detach('Base','eject_page',[$page]);
		}
	}

	my $plid = modifie_prelevemt($vars,$pid);
	if ( ! $pid ) {
		# C'est en fait une creation. Il faut faire un nouveau PDF !
		set_tex_config('adsl/tex.cfg');
		my $prel = prelevemt_par_id($plid);
		my $dir = 'adhacc-'.$prel->{'CLIENT_ID'};
		my $prl = make_pdf_file('mandat-sepa',$dir.'/prel'.$plid, {
				'NUMADH'    => $vars->{numadh},
				'NOM'	    => $vars->{nomdflt},
				'ADRESSE'   => $vars->{adressedflt},
				'CP'	    => $vars->{cpdflt},
				'VILLE'     => $vars->{villedflt},
				'NOMBQ'     => $vars->{nombq},
				'BIC'	    => $vars->{bic},
				'IBAN'	    => $vars->{iban},
				'RUM'	    => $prel->{'PRELEVEMT_MANDAT'},
				});
		
	}
	my $from = $vars->{'from'};
	$c->detach('Base','back_from',[$from]);
}


1;
