package FDN::Adsl::Controller::Prlbq;

use strict;
use warnings;
use base 'FDN::Adsl::Controller::Base';

use FDN::Common::Config;
use FDN::Common::Logger;
use FDN::Web::Array;
use FDN::Web::Forms;
use FDN::Web::TemplateParse;
use FDN::TeX::TeX;

use FDN::Adsl::Basic;
use FDN::Adsl::Utils;
use FDN::Adsl::New;
use FDN::Adsl::Factu;
use FDN::Adsl::Prelevemt;

__PACKAGE__->config->{'namespace'} = 'adsl/prlbq';


sub _new :Path('new') {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;

	my $form = form_read('adsl/form/factu.cfg','nprlbq');
	if ( $vars->{'do'} ne 'yes' ) {
		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}
	if ( !check_transition($form,$vars) ) {
		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}

	my $annee = $vars->{annee};
	$annee =~ s/^annee//;
	my $mois = $vars->{mois};
	$mois =~ s/^mois//;
	my $jour = $vars->{jour};

	my @jours = jours($annee);
	my $nb_jours = $jours[$mois-1];
	if ( $jour > $nb_jours ) {
		$errors = { 'syntax' => [ { err => "Il n'y a pas tant de jours ce mois-la, je n'en compte que ".$nb_jours } ] };
		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}

	$jour =~ s/^(\d)$/0$1/;

	# Creation effective du prelevement
	# On fait maintenant du SEPA, on peut ecrire des dates plus serieuses.
	creation_prelevement(
		$vars->{nom},
		$annee, $mois,
		"prl-$annee-$mois-$jour.xml",
		"$annee-$mois-$jour");

	$c->res->redirect('/adsl/prlbq/liste?last=12');
}

sub liste :Local {
	my ( $self, $c, $what ) = @_;
	$what //= 'all';

	my $vars = $c->req->params;
	my $limit;
	my @pls;

	if ( exists $vars->{'last'} ) {
		$limit = $vars->{'last'};
		@pls = prlbq_recents($limit);
	} elsif ( $what eq 'all' ) {
		@pls = tous_prlbqs();
	} else {
		$c->detach('Base','eject_page',[ "Je n'ai pas compris, tu veux $what ??" ]);
	}

	my @res;
	for my $pl ( @pls ) {
		my $tmp = dispatch_prlbq_tva($pl->{'PRLBQ_ID'});
		push @res, { %$tmp, %$pl };
	}

	my $page = $self->large_table_2d($c, 'prlbq', \@res, "Liste des prlvements");
	$c->forward('Base', 'eject_page', [ $page ]);
}

sub view :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $page;

	my $form = form_read('adsl/form/view.cfg','vprlbq');
	if ( $vars->{'do'} ne 'yes' ) {
		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}
	if ( !check_transition($form,$vars) ) {
		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}

	my $pid = $vars->{'pid'};
	my $prlbq = prlbq_par_id($pid);

	if (! defined $prlbq ) {
		$c->detach('Base','eject_error',["Cette crance n'existe pas."]);
	}

	$page .= $self->small_table_1d($c,'prlbq',$prlbq,"Description du prlvement");

	my @prls;
	if ( $prlbq->{'PRLBQ_TYPE'} eq 'sepa' ) {
		@prls = prlligsepa_par_prlbq_id($pid);
		$page .= $self->large_table_2d($c,'prlligsepa',\@prls,"Lignes du prlvement");
	} else {
		@prls = prllig_par_prlbq_id($pid);
		$page .= $self->large_table_2d($c,'prllig',\@prls,"Lignes du prlvement");
	}

	$c->detach('Base','eject_page',[ $page ]);
}

sub print :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;

	my $form = form_read('adsl/form/factu.cfg','pprlbq');
	# Ajoute la liste des prelevements dans l'ordre (dus, envoyes, payes)
	ajoute_liste_prelevements($form);
	if ( $vars->{'do'} ne 'yes' ) {
		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}
	if ( !check_transition($form,$vars) ) {
		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}

	# Affichage du prelevement
	my $pid = $vars->{prlbq};
	$pid =~ s/^prlbq//;
	my $prlbq = prlbq_par_id($pid);
	if ( ! $prlbq ) {
		$c->detach('Base','eject_error',["Ce prlvement n'existe pas."]);
	}
	my $type = $prlbq->{'PRLBQ_TYPE'};

	if ( $vars->{format} eq 'envoi' ) {
		my $dir = Config_Key('adsl/global.cfg','dirs','prldir');
		$dir = '/tmp' if ! defined $dir;
		my $filename = $prlbq->{'PRLBQ_FICHIER'};
		$filename = $dir.'/'.$filename;

		debug "j'affiche $filename";

	        $c->detach('File','txt',[$filename]);
	}

	my $total = 0;
	my @pls;
	my $prelevement;
	if ( $type eq 'sepa' ) {
		$prelevement = 'prelevementsepa';
		@pls = prlligsepa_par_prlbq_id($pid);
		for my $p ( @pls ) {
			$total += $p->{'PRLLIGSEPA_MONTANT'};
		}
	} else {
		$prelevement = 'prelevement';
		@pls = prllig_par_prlbq_id($pid);
		for my $p ( @pls ) {
			$total += $p->{'PRLLIG_MONTANT'};
		}
	}

	#if ( $type eq 'sepa' ) {
	#	$c->detach('Base','eject_error',["Je ne sais pas encore afficher les prlvements SEPA."]);
	#}

	my $hash = {};
	$hash->{nom} = $prlbq->{'PRLBQ_NOM'};
	$hash->{date} = $prlbq->{'PRLBQ_DATE'};
	$hash->{nblig} = scalar @pls;
	$hash->{total} = prt_euro($total);

	if ( $vars->{format} eq 'html' ) {
		$hash->{tableau} = $self->large_table_2d($c,"$prelevement-html",\@pls,"Lignes du prlvement");
		my $dir = Config_Key('adsl/global.cfg','dirs','htmltpl');
		my $page = remplace($dir.'/prelevement.tpl',$hash,1);
		$c->detach('Base','eject_page',[$page]);
	}
	if ( $vars->{format} eq 'text' ) {
		$hash->{tableau} = $self->large_table_2d($c,"$prelevement-text",\@pls,"Lignes du prlvement");
		my $dir = Config_Key('adsl/global.cfg','dirs','texttpl');
		my $page = remplace($dir.'/prelevement.tpl',$hash,1);
		$c->res->content_type('text/plain; charset=iso-8859-1');
		$c->res->body($page);
		return;
	}
	if ( $vars->{format} eq 'pdf' ) {
		my $dir = Config_Key('adsl/global.cfg','dirs','stockpdf');
		my $file = $dir.'/prlbq/prlbq-'.$prlbq->{'PRLBQ_DATE'}.'-'.$prlbq->{PRLBQ_ID}.'.pdf';
		if ( ! -f $file ) {
			debug "File $file not found, creating it.";
			set_tex_config('adsl/tex.cfg');
			$hash->{tableau} = tableau_2d_tex('adsl/rewrite.tbl',"$prelevement-tex",\@pls);
			my $res = make_pdf_file('prlbq','.',$hash);
			system("cp $res $file");
		}
		if ( ! -f $file ) {
			$c->detach('Base','eject_error',["Failed to create pdf file."]);
		}
		$c->detach('File','pdf',[$file]);
	}

	$c->detach('Base','eject_error',["Je n'ai pas compris comment tu voulais voir ce prlvement"]);
}

1;
