package FDN::Adsl::Controller::Prlligsepa;

use strict;
use warnings;
use base 'FDN::Adsl::Controller::Base';

use FDN::Web::Array;
use FDN::Web::Forms;

use FDN::Adsl::Basic;
use FDN::Adsl::New;
use FDN::Adsl::Utils;
use FDN::Adsl::Factu;

__PACKAGE__->config->{'namespace'} = 'adsl/prlligsepa';



sub liste :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $page;

	if ( $vars->{'client'} ) {
		my $cid = $vars->{'client'};
		my $prls = [ prlligsepa_par_client_id($cid) ];
		$prls = [ sort { $a->{PRLLIGSEPA_ID} <=> $b->{PRLLIGSEPA_ID} } @$prls ];
		$page = $self->large_table_2d($c, 'prlligsepa', $prls, "Lignes de prlvement de l'abonn (SEPA)");
	}

	if ( $page ) {
		$c->detach('Base', 'eject_page', [ $page ] );
	}

	$c->detach('Base','eject_error',["C'est idiot de vouloir lister des lignes de prelevement SEPA en vrac"]);
}

sub view :Local {
	my ( $self, $c, $iid ) = @_;

	my $vars = $c->req->params;
	my $page;

	my $form = form_read('adsl/form/view.cfg','vprlligsepa');
	if ( $vars->{'do'} ne 'yes' ) {
		$page = affiche_form($form,$vars);
		$c->detach('Base','eject_page',[$page]);
	}
	if ( !check_transition($form,$vars) ) {
		$page = affiche_form($form,$vars);
		$c->detach('Base','eject_page', [ $page ]);
	}

	my $pid = $vars->{'pid'};
	my $prl = prlligsepa_par_id($pid);

	if ( ! defined $prl ) {
		$c->detach('Base','eject_error',["Cette ligne de prlvement SEPA n'existe pas."]);
	}

	$page .= $self->small_table_1d($c, 'prlligsepa', $prl, "Une ligne d'un prlvement (SEPA)", {
		'Rejeter'   => "/adsl/prlligsepa/rejete?pid=$pid&from=prlligsepa$pid",
		'Encaisser' => "/adsl/prlligsepa/paye?pid=$pid&from=prlligsepa$pid",
	});

	my $crs = [ creance_par_prlligsepa_id($pid) ];
	$crs = [ sort { $a->{CREANCE_ID} <=> $b->{CREANCE_ID} } @$crs ];
	$page .= $self->large_table_2d($c, 'creance', $crs, "Crances couvertes");

	$c->detach('Base','eject_page', [ $page ]);
}

sub paye :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;

	my $pid = $vars->{'pid'};
	my $prl = prlligsepa_par_id($pid);

	if ( ! defined $prl ) {
		$c->detach('Base', 'eject_error', [ "Cette ligne de prlvement n'existe pas." ] );
	}

	encaisser_prlligsepa($prl);

	my $from = $vars->{'from'};
	$c->detach('Base','back_from', [ $from ]);
}

sub rejete :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;

	my $pid = $vars->{'pid'};
	my $prl = prlligsepa_par_id($pid);

	if ( ! defined $prl ) {
		$c->detach('Base', 'eject_error', [ "Cette ligne de prlvement n'existe pas." ] );
	}

	rejeter_prlligsepa($prl);

	my $from = $vars->{'from'};
	$c->detach('Base','back_from', [ $from ]);
}


1;
