package FDN::Adsl::Controller::Vpn;

use strict;
use warnings;
use base 'FDN::Adsl::Controller::Base';

use FDN::Common::Config;
use FDN::Web::Array;
use FDN::Web::Forms;

use FDN::Adsl::Basic;
use FDN::Adsl::Infos;
use FDN::Adsl::Liste;
use FDN::Adsl::New;
use FDN::Adsl::Utils;
use FDN::Sql::Workflow::Run;

__PACKAGE__->config->{'namespace'} = 'adsl/vpn';

sub liste :Local {
	my ( $self, $c ) = @_;

	my $page;
	if ( $c->req->param('cid') ) {
		my $cid = $c->req->param('cid');
		my $vpn = [ vpn_par_client_id($cid) ];
		$vpn = [ sort { $a->{VPN_ID} <=> $b->{VPN_ID} } @$vpn ];
		$page = $self->large_table_2d($c, 'vpn', $vpn, "VPN de l'abonn");
	} else {
		my $sort = $c->req->param('sort');
		$page = liste_vpns($sort);
	}

	$c->detach('Base','eject_page',[ $page ]);
}

sub view :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $page = '';

	my $form = form_read('adsl/form/view.cfg','vvpn');

	if ( $vars->{'do'} ne 'yes' ) {
		$c->detach('Base','eject_page',[ affiche_form($form,$vars)  ]);
	}
	if ( !check_transition($form,$vars) ) {
		$c->detach('Base','eject_page',[ affiche_form($form,$vars)  ]);
	}

	my $vid = $vars->{'vid'};
	my $vpn = vpn_par_id($vid);
	if ( ! defined $vpn ) {
		$c->detach('Base','eject_error',["Ce VPN n'existe pas"]);
		exit(0);
	}

	my $cid = $vpn->{'CLIENT_ID'};
	$page .= $self->small_table_1d($c,'vpn-detail',$vpn, "Description du VPN", {
		'Modifier' => '/adsl/vpn/new?id='.$vid,
		'Resilier' => '/adsl/vpn/resil?id='.$vid
	});

	my @users = raduser_par_vpn_id($vid);
	for my $user ( @users ) {
		$page .= $self->small_table_1d($c,'raduser',$user, "Compte radius associ", {
		});
	}

	my $aid = $vpn->{'ADRESSE_ID'};
	my $adr = adresse_par_id($aid);
	$page .= $self->small_table_1d($c,'adresse',$adr, "Adresse du vpn ", {
		'Modifier' => '/adsl/adresse/new?id='.$aid.'&from=vpn'.$vid
	});

	my @infos = toutes_infos_vpn($vid);
	@infos = sort { $a->{INFO_ID} <=> $b->{INFO_ID} } @infos;
	$page .= tableau_2d('adsl/rewrite.tbl','infos',\@infos,
		"Informations sur le vpn".
		forward_to('nscan',"&vpn=$vid&client=$cid","vpn$vid"));

	$c->detach('Base','eject_page',[ $page ]);
}

sub _new :Path('new') {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $id = $vars->{id};
	my $form = form_vpn($vars);
	my $page;

	if ( $vars->{'do'} ne 'yes' ) {
		renseigne_vpn($vars,$id);
		if ( defined $id ) {
			my @infos = toutes_infos_vpn($id);
			my $tmp = tableau_2d('adsl/rewrite.tbl','infos',\@infos);
			my $fld = $form->{'byname'}->{'infos'};
			form_set_field_value($fld,$tmp);
		}
		$page = affiche_form($form,$vars);
		$c->detach('Base','eject_page',[ $page ]);
	}
	if ( !check_transition($form,$vars) ) {
		$page = affiche_form($form,$vars);
		$c->detach('Base','eject_page',[ $page ]);
	}
	modifie_vpn($vars,$id);
	$c->res->redirect("/adsl/vpn/view?vid=$id&do=yes");
}


sub resil :Local {
	my ( $self, $c ) = @_;
	my $vars = $c->req->params;
	my $vid = $vars->{id};
	my $page;

	my $vpn = vpn_par_id($vid);
	if ( ! $vpn ) {
		$c->detach('Base','eject_error',["Ce VPN n'existe pas"]);
	}
	my $cid = $vpn->{'CLIENT_ID'};

	if ( ! $vars->{'ok'} ) {
		$page = "<form action=\"resil\">\n".
			"<p>Vous allez resilier le VPN $vid. C'est definitif, et a partir de tout de suite. Merci de confirmer.</p>\n".
			"<input type=\"hidden\" name=\"ok\" value=\"ok\" />\n".
			"<input type=\"hidden\" name=\"id\" value=\"$vid\" />\n".
			"<p>Pour annuler <a href=\"../client/view?cid=$cid&do=yes\">retour sur la fiche de l'adherent.</p>\n".
			"<input name=\"go\" type=\"submit\" value=\"Ok\" />\n".
			"</form>";
		$c->detach('Base','eject_page',[ $page ]);
	}
		
	new_info_vpn($vid,'inline','Resiliation','Resiliation par FDN via le SI.');
	if ( $vpn->{'VPN_STATE'} eq 'new' ) {
		set_vpn_state($vid,'del');
		$page = '<p>La commande de ce VPN a t annule.</p>';
		$c->detach('Base','eject_page',[ $page ]);
	}

	if ( $vpn->{'VPN_STATE'} eq 'del' ) {
		$page = '<p>Ce VPN est dj rsili.</p>';
		$c->detach('Base','eject_page',[ $page ]);
	}


	workflow_select_db('adsl');
	workflow_select_config('adsl/wf.cfg');
	my $tid = launch_task('resil-vpn',{ vpnid => $vid });
	if ( ! $tid ) {
		$page = "<p>Echec. Je n'ai pas pu lancer la tache de rsiliation. Il faut contacter FDN...</p>";
		$c->detach('Base','eject_error',[$page]);
	}
	$page = "<p>La rsiliation est lance. Elle sera effective dans quelques minutes.</p>";
	$c->detach('Base','eject_page',[ $page ]);
}

sub liste_fas :Local {
	my ( $self, $c ) = @_;

	my @vpns = vpn_par_state('new');
	my $page = tableau_2d('adsl/rewrite.tbl','vpn-fas',\@vpns);
	$c->detach('Base','eject_page',[$page ]);
}

sub show_fas :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $vid = $vars->{'vid'};
	my $vpn = vpn_par_id($vid);
	my $cid = $vpn->{'CLIENT_ID'};
	my $client = client_par_id($cid);
	my $page;
	my @infos;

	$page  = tableau_1d('adsl/rewrite.tbl','vpn',$vpn,"Description du VPN");
	$page .= tableau_1d('adsl/rewrite.tbl','client',$client,"Description du client");

	@infos = toutes_infos_vpn($vid);
	@infos = sort { $a->{INFO_ID} <=> $b->{INFO_ID} } @infos;
	$page .= tableau_2d('adsl/rewrite.tbl','infos',\@infos,"Informations sur le VPN");

	@infos = toutes_infos_client($cid);
	@infos = sort { $a->{INFO_ID} <=> $b->{INFO_ID} } @infos;
	$page .= tableau_2d('adsl/rewrite.tbl','infos',\@infos,"Informations sur le client");

	$page .= "<p>Il faut vrifier la prsence de tous ces lments:<br>\n".
		 "<b>Nouvel adhrent:</b></p>\n".
		 "<ul>\n".
		 "<li>l'image du bulletin d'adhsion;</li>\n".
		 "<li>l'image de l'autorisation de prlvement;</li>\n".
		 "<li>la saisie du RIB pour le prlvement (l'item &nbsp;Paiment&nbsp;\n".
		 "    dans la description du client ne doit pas mentionner de Facture, mais\n".
		 "    l'identifiant du RIB);</li>\n".
		 "<li>l'image de la pice d'identit de l'adhrent;</li>\n".
		 "<li>l'image du justificatif (carte d'tudiant, etc) si l'adhrent\n".
		 "    demande le tarif prfrentiel.\n".
		 "</ul>\n".
		 "<p>Si un des lments manque, il faut retourner le scanner, ou attendre\n".
		 "de le recevoir selon le cas. <b>Ne pas valider de ligne s'il manque des\n".
		 "documents!</b></p>";
	
	$page .= '<p><a href="paye_fas?vid='.$vid.'&do=yes">Valider</a></p>';
	$c->detach('Base','eject_page',[ $page	]);
}

sub paye_fas :Local {
	my ( $self, $c ) = @_;
	my $vars = $c->req->params;
	my $vid = $vars->{'vid'};
	my $vpn = vpn_par_id($vid);
	my $cid = $vpn->{'CLIENT_ID'};
	my $client = client_par_id($cid);
	if ($client->{'CLIENT_NUMADH'} < 0 && $client->{'CLIENT_TYPE'} ne 'blanche' && $client->{'CLIENT_TYPE'} ne 'collecte') {
		$c->detach('Base','eject_error',["Le.la futur.e abonn.e n'est pas encore adhrent, il faut d'abord vrifier son adhsion et cliquer sur 'Initialiser'"]);
		exit(0);
	}
	my $event = 'FAS-vpn'.$vpn->{'VPN_ID'};
	workflow_select_db('adsl');
	send_event($event);
	$c->res->redirect('/adsl');
}

1;
