package FDN::Adsl::View::File;

use strict;
use warnings;
use base 'Catalyst::View';
use Encode;

sub __asname($;$) {
	my ( $file, $asname ) = @_;
	if ( ! defined $asname ) {
		$asname = $file;
		$asname =~ s/^(.*)?\/([^\/]+)$/$2/;
	}
	return $asname;
}

sub send_file {
	my ( $self, $c, $mime, $file, $asname ) = @_;
	$asname = __asname($file, $asname);
	$c->response->content_type($mime);
	$c->response->headers->header( 'Content-Disposition' => 'inline; filename="'.$asname.'"' );
	$c->response->headers->header( 'Expires' => '-1' );

	$c->log->debug("Sending $file as $mime with name $asname");
	local $/;
	open FILE, $file;
	my $res=<FILE>;
	close FILE;

	$c->response->body($res);
}

sub pdf {
	my ( $self, $c, $file ) = @_;
	$c->forward('File', 'send_file', [ 'application/pdf', $file ]);
}

sub txt {
	my ( $self, $c, $file ) = @_;
	$c->forward('File', 'send_file', [ 'text/plain', $file ]);
}

sub send_html_file($;$) {
	my ( $file, $asname ) = @_;
	__send_file($file,'text/html; charset=ISO-8859-1',$asname);
}

sub send_png_file($;$) {
	my ( $file, $asname ) = @_;
	__send_file($file,'image/png',$asname);
}

sub send_jpeg_file($;$) {
	my ( $file, $asname ) = @_;
	__send_file($file,'image/jpeg',$asname);
}


sub send_ps_file($;$) {
	my ( $file, $asname ) = @_;
	__send_file($file,'application/postscript', $asname);
}

1;


